@@ -99,13 +99,22 @@ sub class_to_file {
     $class . ".pm";
 }
 
+sub _load_sandbox {
+    my $_file = shift;
+
+    my $_package = $_file;
+    $_package =~ s/([^A-Za-z0-9_])/sprintf("_%2x", unpack("C", $1))/eg;
+
+    eval "package Plack::Sandbox::$_package; do(\$_file)";
+}
+
 sub load_psgi {
     my $stuff = shift;
 
     local $ENV{PLACK_ENV} = $ENV{PLACK_ENV} || 'development';
 
     my $file = $stuff =~ /^[a-zA-Z0-9\_\:]+$/ ? class_to_file($stuff) : $stuff;
-    my $app = do $file;
+    my $app = _load_sandbox($file);
     return $app->to_app if $app and Scalar::Util::blessed($app) and $app->can('to_app');
     return $app if $app and (ref $app eq 'CODE' or overload::Method($app, '&{}'));
 
